@@ -196,13 +196,23 @@ class Chemical:
     
     Other Parameters
     ----------------
-    search_ID=None : str
+    search_ID=None : str, optional
         ID to search through database. Pass this key-word argument
         when you'd like to give a custom name to the chemical, but
         cannot find the chemical with that name.
-    eos : GCEOS subclass, optional
+    eos=PengRobinson : GCEOS subclass, optional
         Equation of state class for solving thermodynamic properties.
         Defaults to Peng-Robinson.
+    CAS=None : str, optional
+        CAS number of chemical.
+    default=False : bool, optional
+        Whether to default any missing chemical properties such as molar volume,
+        heat capacity, surface tension, thermal conductivity, and molecular weight
+        to that of water (on a weight basis).
+    phase=None: {'s', 'l' or 'g'}, optional
+        Phase to set state of chemical.
+    search_db=False: bool, optional
+        Whether to search the data base for chemical.
     **data : float or str
         User data (e.g. Tb, formula, etc.).
     
@@ -481,17 +491,22 @@ class Chemical:
     ### Creators ###
     
     def __new__(cls, ID, *, search_ID=None,
-                eos=PR, phase_ref=None, **data):
+                eos=PR, phase_ref=None,
+                default=False, phase=None,
+                CAS=None, search_db=True,
+                V=None, Cn=None, mu=None, Cp=None, rho=None,
+                sigma=None, kappa=None, epsilon=None,
+                **data):
         cache = cls._cache
-        search_ID = search_ID or ID
+        search_ID = search_ID or CAS or ID
         try:
             CAS = CAS_from_any(search_ID)
         except Exception as Error:
             search_ID = to_searchable_format(search_ID)
             try: CAS = CAS_from_any(search_ID)
-            except: raise Error
-        
-        if CAS in cache:
+            except:
+                if search_db: raise Error
+        if search_db and CAS in cache:
             self = cache[CAS]
             if ID != self._ID:
                 if ID in cache:
@@ -502,10 +517,22 @@ class Chemical:
             for i,j in data.items(): 
                 if j is not None: setfield(self, i, j)
         else:
-            self = super().__new__(cls)
-            self._ID = ID
-            self.reset(CAS, eos, phase_ref, **data)
+            if CAS:
+                self = super().__new__(cls)
+                self._ID = ID
+                self.reset(CAS, eos, phase_ref, **data)
+            else:
+                self = cls.blank(ID, CAS, phase_ref, **data)                
             cache[CAS] = self
+        if phase: self = self.at_state(phase, copy=True)
+        if mu: self.mu.add_model(mu, top_priority=True)
+        if Cn: self.Cn.add_model(Cn, top_priority=True)
+        if kappa: self.kappa.add_model(kappa, top_priority=True)
+        if sigma: self.sigma.add_model(sigma, top_priority=True)
+        if epsilon: self.sigma.add_model(epsilon, top_priority=True)
+        if Cp: self.Cn.add_model(Cp * self.MW, top_priority=True)
+        if rho: self.V.add_model(fn.rho_to_V(rho, self.MW), top_priority=True)
+        if default: self.default()
         return self
 
     @classmethod
@@ -611,8 +638,6 @@ class Chemical:
 
     def copy(self, ID, CAS=None):
         """Return a copy of the chemical with a new ID."""
-        cache = self._cache
-        CAS = CAS or ID
         new = super().__new__(self.__class__)
         getfield = getattr
         setfield = setattr
@@ -625,7 +650,6 @@ class Chemical:
         new._init_energies(new.Cn, new.Hvap, new.Psat, new.Hfus, new.Tm,
                            new.Tb, new.eos, new.eos_1atm, new.phase_ref,
                            new._locked_state)
-        cache[CAS] = new
         new._label_handles()
         return new
     __copy__ = copy
@@ -1678,6 +1702,7 @@ class Chemical:
             new.at_state(phase)
             return new
         locked_state = self._locked_state
+        phase = phase.lower()[0]
         if locked_state:
             if locked_state != phase:
                 raise TypeError(f"{self}'s state is already locked")   
