@@ -5,7 +5,7 @@ Functional utilities for the calculation of thermodynamic properties.
 """
 from fluids.core import thermal_diffusivity
 from cmath import sqrt as csqrt
-from .utils import njitable
+from flexsolve import njitable
 from .base import functor
 from ._constants import R
 import numpy as np
@@ -33,7 +33,7 @@ def Pr(Cp, mu, k):
     return Cp * mu / k
 
 def mu_to_nu(mu, rho):
-    r'''
+    r"""
     Return the kinematic viscosity (nu) given the dynamic viscosity (mu) and 
     density (rho).
 
@@ -45,11 +45,7 @@ def mu_to_nu(mu, rho):
     >>> mu_to_nu(0.000998, 998.)
     1.0e-06
 
-    References
-    ----------
-    .. [1] Cengel, Yunus, and John Cimbala. Fluid Mechanics: Fundamentals and
-       Applications. Boston: McGraw Hill Higher Education, 2006.
-    '''
+    """
     return mu/rho
 
 def V_to_rho(V, MW):
@@ -1283,7 +1279,7 @@ polylog2._pqoffset2 = ((8.548256176424551e+34, 1.8485781239087334e+35,
                        0.999)
 
 @njitable
-def normalize(array, minimum=1e-12):
+def normalize(array, minimum=1e-16):
     """
     Return a normalized array to a magnitude of 1.
     If magnitude is zero, all fractions will have equal value.
@@ -1297,26 +1293,9 @@ def normalize(array, minimum=1e-12):
         return array/sum_array
 
 @njitable
-def mixing_simple(fracs, props):
+def mixing_simple(z, y):
     r'''
-    Simple function calculates a property based on weighted averages of
-    properties. Weights could be mole fractions, volume fractions, mass
-    fractions, or anything else.
-
-    .. math::
-        y = \sum_i \text{frac}_i \cdot \text{prop}_i
-
-    Parameters
-    ----------
-    fracs : array-like
-        Fractions of a mixture
-    props: array-like
-        Properties
-
-    Returns
-    -------
-    prop : value
-        Calculated property
+    Return a weighted average of `y` given the weights, `z`.
 
     Examples
     --------
@@ -1324,36 +1303,19 @@ def mixing_simple(fracs, props):
     0.019000000000000003
     
     '''
-    fracs = np.asarray(fracs)
-    props = np.asarray(props)
-    return (fracs * props).sum()
+    return (np.asarray(z, float) * np.asarray(y, float)).sum()
 
 @njitable
-def mixing_logarithmic(fracs, props):
+def mixing_logarithmic(z, y):
     r'''
-    Simple function calculates a property based on weighted averages of
-    logarithmic properties.
+    Return the logarithmic weighted average `y` given weights, `z`.
 
     .. math::
-        y = \sum_i \text{frac}_i \cdot \log(\text{prop}_i)
-
-    Parameters
-    ----------
-    fracs : array-like
-        Fractions of a mixture
-    props: array-like
-        Properties
-
-    Returns
-    -------
-    prop : value
-        Calculated property
+        y = \sum_i z_i \cdot \log(y_i)
 
     Notes
     -----
     Does not work on negative values.
-    Returns None if any fractions or properties are missing or are not of the
-    same length.
 
     Examples
     --------
@@ -1361,5 +1323,5 @@ def mixing_logarithmic(fracs, props):
     0.01866065983073615
     
     '''
-    return np.exp((fracs*np.log(props)).sum())
+    return np.exp((z*np.log(y)).sum())
 
